yaleBraille-package: Data visualization tools for low-vision and blind end-users

yaleBraille-packageR Documentation

Data visualization tools for low-vision and blind end-users

Description

This package provides plotting functions similar to those found in Base R, but with _br suffixes, indicating Braille-functionality. These functions deliver as output a two-page .pdf file: first page is a braille-annotated graph; second page is the text-based graph. Coding occurs via conventional syntax (i.e. text); translation is executed by the liblouis package. Graphical standards are adapted to facilitate printing onto swell-paper. For more information see <https://github.com/wininger/yaleBraille>.

Author(s)

Mike Wininger, michael.wininger@yale.edu

Examples

  
    library(yaleBraille)
    data(yaleSports)
    translateToBraille(yaleSports$Sport[1], table = "en-ueb-g2.ctb")
    plot_br(Weight~Height, data=yaleSports)
  

yaleBraille documentation built on Oct. 2, 2026, 5:08 p.m.