| yaleBraille-package | R Documentation |
This package provides plotting functions similar to those found in Base R, but with _br suffixes, indicating Braille-functionality. These functions deliver as output a two-page .pdf file: first page is a braille-annotated graph; second page is the text-based graph. Coding occurs via conventional syntax (i.e. text); translation is executed by the liblouis package. Graphical standards are adapted to facilitate printing onto swell-paper. For more information see <https://github.com/wininger/yaleBraille>.
Mike Wininger, michael.wininger@yale.edu
library(yaleBraille)
data(yaleSports)
translateToBraille(yaleSports$Sport[1], table = "en-ueb-g2.ctb")
plot_br(Weight~Height, data=yaleSports)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.